@@ -1,13 +1,8 @@
 from __future__ import absolute_import
 
-import io
-import warnings
-from os import path
-
 from flask import request, session, flash, Blueprint, url_for, send_file
-import jinja2 as jinja
 
-from webgrid.extensions import translation_manager
+from webgrid.extensions import FrameworkManager, translation_manager
 
 try:
     from morphi.helpers.jinja import configure_jinja_environment
@@ -15,7 +10,7 @@ except ImportError:
     configure_jinja_environment = lambda *args, **kwargs: None  # noqa: E731
 
 
-class WebGrid(object):
+class WebGrid(FrameworkManager):
     """Grid manager for connecting grids to Flask webapps.
 
     Instance should be assigned to the manager attribute of a grid class::
@@ -30,17 +25,13 @@ class WebGrid(object):
     Class Attributes:
         jinja_loader (jinja.Loader): Template loader to use for HTML rendering.
 
+        args_loaders (ArgsLoader[]): Iterable of classes to use for loading grid args, in order
+        of priority
+
+        session_max_hours (int): Hours to hold a given grid session in storage. Set to None to
+        disable. Default 12.
+
     """
-    jinja_loader = jinja.PackageLoader('webgrid', 'templates')
-
-    def __init__(self, db=None):
-        self.init_db(db)
-        self.jinja_environment = jinja.Environment(
-            loader=self.jinja_loader,
-            finalize=lambda x: x if x is not None else '',
-            autoescape=True
-        )
-
     def init_db(self, db):
         """Set the db connector."""
         self.db = db
@@ -69,10 +60,6 @@ class WebGrid(object):
         """Return request."""
         return request
 
-    def static_path(self):
-        """Path containing static assets (images, CSS, JS)."""
-        return path.join(path.dirname(__file__), 'static')
-
     def static_url(self, url_tail):
         """Construct static URL from webgrid blueprint."""
         return url_for('webgrid.static', filename=url_tail)
@@ -92,11 +79,3 @@ class WebGrid(object):
         """Return response from framework for sending a file."""
         return send_file(data_stream, mimetype=mime_type, as_attachment=True,
                          attachment_filename=file_name)
-
-    def xls_as_response(self, workbook, file_name):
-        warnings.warn('xls_as_response is deprecated. Use file_as_response instead',
-                      DeprecationWarning)
-        buf = io.BytesIO()
-        workbook.save(buf)
-        buf.seek(0)
-        return self.file_as_response(buf, file_name, 'application/vnd.ms-excel')
